JBoss Tools SVN: r12968 - in trunk/vpe/plugins: org.jboss.tools.vpe.html/src/org/jboss/tools/vpe/html/template and 1 other directory.
by jbosstools-commits@lists.jboss.org
Author: yradtsevich
Date: 2009-01-10 08:43:11 -0500 (Sat, 10 Jan 2009)
New Revision: 12968
Modified:
trunk/vpe/plugins/org.jboss.tools.vpe.html/src/org/jboss/tools/vpe/html/template/HtmlTextTemplate.java
trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/util/VisualDomUtil.java
Log:
Method createBorderlessContainer was created in the class VisualDomUtil.
Modified: trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/util/VisualDomUtil.java
===================================================================
--- trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/util/VisualDomUtil.java 2009-01-10 13:25:41 UTC (rev 12967)
+++ trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/util/VisualDomUtil.java 2009-01-10 13:43:11 UTC (rev 12968)
@@ -18,6 +18,7 @@
import org.eclipse.swt.graphics.Rectangle;
import org.mozilla.interfaces.nsIAccessibilityService;
import org.mozilla.interfaces.nsIAccessible;
+import org.mozilla.interfaces.nsIDOMDocument;
import org.mozilla.interfaces.nsIDOMElement;
import org.mozilla.interfaces.nsIDOMEvent;
import org.mozilla.interfaces.nsIDOMMouseEvent;
@@ -263,4 +264,23 @@
return bounds;
}
+
+ /**
+ * Creates HTML container (element) borders of that are
+ * complete invisible to user.
+ * <P>
+ * It can be used to wrap visual HTML elements and text nodes without
+ * changing of their view in VPE.
+ *
+ * @param visualDocument the visual document. It is used to create the container.
+ * @return created borderless container
+ *
+ * @author yradtsevich
+ */
+ public static nsIDOMElement createBorderlessContainer(
+ nsIDOMDocument visualDocument) {
+ nsIDOMElement element = visualDocument.createElement(HTML.TAG_SPAN);
+ element.setAttribute(HTML.ATTR_CLASS, HTML.CLASS_VPE_TEXT);
+ return element;
+ }
}
Modified: trunk/vpe/plugins/org.jboss.tools.vpe.html/src/org/jboss/tools/vpe/html/template/HtmlTextTemplate.java
===================================================================
--- trunk/jsf/tests/org.jboss.tools.jsf.vpe.jsf.test/src/org/jboss/tools/jsf/vpe/jsf/test/jbide/JBIDE3441Test.java 2009-01-10 11:49:33 UTC (rev 12966)
+++ trunk/jsf/tests/org.jboss.tools.jsf.vpe.jsf.test/src/org/jboss/tools/jsf/vpe/jsf/test/jbide/JBIDE3441Test.java 2009-01-10 13:25:41 UTC (rev 12967)
@@ -14,7 +14,6 @@
import org.eclipse.core.resources.IFile;
import org.eclipse.core.runtime.CoreException;
-import org.eclipse.swt.widgets.Display;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.PlatformUI;
@@ -52,15 +51,12 @@
VpeController controller1 = openPageInVpe(TEST_PAGE_NAME_1);
VpeController controller2 = openPageInVpe(TEST_PAGE_NAME_2);
-
- Display display = Display.getCurrent();
+
for (int i = 0; i < 20; i++) {
controller1.visualRefresh();
controller2.visualRefresh();
- while(display.readAndDispatch());
+ TestUtil.delay(500);
TestUtil.waitForJobs();
- Thread.sleep(500);
-
checkTaggedDivValue(controller1, i);
checkTaggedDivValue(controller2, i);
}
Modified: trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/VpeController.java
===================================================================
--- trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/VpeController.java 2009-01-10 11:49:33 UTC (rev 12966)
+++ trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/VpeController.java 2009-01-10 13:25:41 UTC (rev 12967)
@@ -181,11 +181,7 @@
private boolean sourceChangeFlag;
private VpePageContext pageContext;
private BundleMap bundle;
- private VpeEditorPart editPart;
- private static final int AROUND_MENU = 1;
- private static final int BEFORE_MENU = 2;
- private static final int AFTER_MENU = 3;
-
+ private VpeEditorPart editPart;
private static final int LEFT_BUTTON = 0;
private CSSReferenceList cssReferenceListListener;
@@ -209,6 +205,7 @@
* when{@link #vpeVisualRefreshJob} is accessed.
*/
private final Object vpeVisualRefreshJobLock = new Object();
+ private UIJob reinitJob;
/**
* Added by Max Areshkau JBIDE-675, stores information about modification
@@ -2618,28 +2615,6 @@
}
/**
- * @return the progressMonitor
- */
- private IProgressMonitor getProgressMonitor() {
-
- if (progressMonitor == null) {
-
- progressMonitor = Job.getJobManager().createProgressGroup();
- }
-
- return progressMonitor;
- }
-
- /**
- * @param progressMonitor
- * the progressMonitor to set
- */
- private void setProgressMonitor(IProgressMonitor progressMonitor) {
-
- this.progressMonitor = progressMonitor;
- }
-
- /**
* @return the changeEvents
*/
public LinkedList<VpeEventBean> getChangeEvents() {
@@ -2650,8 +2625,26 @@
}
return changeEvents;
}
+
+ public void reinit(){
+ if(reinitJob!=null) {
+ reinitJob.cancel();
+ }
+ reinitJob = new UIJob(VpeUIMessages.VPE_VISUAL_REFRESH_JOB) {
- public void reinit() {
+ @Override
+ public IStatus runInUIThread(IProgressMonitor monitor) {
+ if(monitor.isCanceled()) {
+ return Status.CANCEL_STATUS;
+ }
+ reinitImpl();
+ return Status.OK_STATUS;
+ }
+ };
+ reinitJob.schedule();
+ }
+
+ private void reinitImpl() {
try {
if(!switcher
.startActiveEditor(ActiveEditorSwitcher.ACTIVE_EDITOR_SOURCE)) {
16 years
JBoss Tools SVN: r12966 - trunk/vpe/plugins/org.jboss.tools.vpe.
by jbosstools-commits@lists.jboss.org
Author: sdzmitrovich
Date: 2009-01-10 06:49:33 -0500 (Sat, 10 Jan 2009)
New Revision: 12966
Modified:
trunk/vpe/plugins/org.jboss.tools.vpe/plugin.xml
Log:
https://jira.jboss.org/jira/browse/JBIDE-3517
Modified: trunk/vpe/plugins/org.jboss.tools.vpe/plugin.xml
===================================================================
--- trunk/vpe/plugins/org.jboss.tools.vpe/plugin.xml 2009-01-10 01:06:59 UTC (rev 12965)
+++ trunk/vpe/plugins/org.jboss.tools.vpe/plugin.xml 2009-01-10 11:49:33 UTC (rev 12966)
@@ -104,13 +104,4 @@
</dynamic>
</menuContribution>
</extension>
- <extension
- point="org.eclipse.ui.commands">
- <command
- id="org.jboss.tools.vpe.insert"
- name="org.jboss.tools.vpe.insert"
- defaultHandler="org.jboss.tools.vpe.editor.menu.InsertAction"
- >
- </command>
- </extension>
</plugin>
16 years
JBoss Tools SVN: r12965 - workspace/examples.
by jbosstools-commits@lists.jboss.org
Author: dgolovin
Date: 2009-01-09 20:06:59 -0500 (Fri, 09 Jan 2009)
New Revision: 12965
Modified:
workspace/examples/projectExamples.xml
Log:
RichFaces Example added to Project Examples
Modified: workspace/examples/projectExamples.xml
===================================================================
--- workspace/examples/projectExamples.xml 2009-01-10 00:57:08 UTC (rev 12964)
+++ workspace/examples/projectExamples.xml 2009-01-10 01:06:59 UTC (rev 12965)
@@ -320,4 +320,15 @@
http://anonsvn.jboss.org/repos/jbosstools/workspace/grid/esb-example/tran...
</url>
</project>
+ <project>
+ <category>RichFaces</category>
+ <name>RichFaces 3.2.2.SP1 Demo Application for JBoss AS 4.2.X</name>
+ <included-projects>richfaces-demo</included-projects>
+ <shortDescription>RichFaces 3.2.2.SP1 Demo Application - WAR</shortDescription>
+ <description>This example contains RichFaces 3.2.2.SP1 Demo Application</description>
+ <size>10640749</size>
+ <url>
+ http://anonsvn.jboss.org/repos/jbosstools/workspace/dgolovin/examples/rf/...
+ </url>
+ </project>
</projects>
16 years
JBoss Tools SVN: r12964 - workspace/dgolovin/org.jboss.tools.project.examples.rf.demo.
by jbosstools-commits@lists.jboss.org
Author: dgolovin
Date: 2009-01-09 19:57:08 -0500 (Fri, 09 Jan 2009)
New Revision: 12964
Modified:
workspace/dgolovin/org.jboss.tools.project.examples.rf.demo/rf-demo-projects.xml
Log:
Modified: workspace/dgolovin/org.jboss.tools.project.examples.rf.demo/rf-demo-projects.xml
===================================================================
--- workspace/dgolovin/org.jboss.tools.project.examples.rf.demo/rf-demo-projects.xml 2009-01-09 20:38:42 UTC (rev 12963)
+++ workspace/dgolovin/org.jboss.tools.project.examples.rf.demo/rf-demo-projects.xml 2009-01-10 00:57:08 UTC (rev 12964)
@@ -2,11 +2,11 @@
<project>
<category>RichFaces</category>
- <name>RichFaces Demo Application for Tomcat6</name>
+ <name>RichFaces 3.2.2.SP1 Demo Application for JBoss AS 4.2.X</name>
<included-projects>richfaces-demo</included-projects>
- <shortDescription>RichFaces 3.2.2.SP1 Demo Application (Tomcat6) - WAR</shortDescription>
+ <shortDescription>RichFaces 3.2.2.SP1 Demo Application - WAR</shortDescription>
<description>This example contains RichFaces 3.2.2.SP1 Demo Application</description>
- <size>11724521</size>
+ <size>10640749</size>
<url>http://anonsvn.jboss.org/repos/jbosstools/workspace/dgolovin/examples/rf/...</url>
</project>
</projects>
\ No newline at end of file
16 years
JBoss Tools SVN: r12963 - trunk/jsf/plugins/org.jboss.tools.jsf.vpe.jsf/src/org/jboss/tools/jsf/vpe/jsf/template.
by jbosstools-commits@lists.jboss.org
Author: dmaliarevich
Date: 2009-01-09 15:38:42 -0500 (Fri, 09 Jan 2009)
New Revision: 12963
Modified:
trunk/jsf/plugins/org.jboss.tools.jsf.vpe.jsf/src/org/jboss/tools/jsf/vpe/jsf/template/JsfFacet.java
Log:
https://jira.jboss.org/jira/browse/JBIDE-3416, f:facet processing was updated.
Modified: trunk/jsf/plugins/org.jboss.tools.jsf.vpe.jsf/src/org/jboss/tools/jsf/vpe/jsf/template/JsfFacet.java
===================================================================
--- trunk/jsf/plugins/org.jboss.tools.jsf.vpe.jsf/src/org/jboss/tools/jsf/vpe/jsf/template/JsfFacet.java 2009-01-09 14:14:01 UTC (rev 12962)
+++ trunk/jsf/plugins/org.jboss.tools.jsf.vpe.jsf/src/org/jboss/tools/jsf/vpe/jsf/template/JsfFacet.java 2009-01-09 20:38:42 UTC (rev 12963)
@@ -34,6 +34,7 @@
private static String JSF_HTML_URI = "http://java.sun.com/jsf/html"; //$NON-NLS-1$
private static String RICH_FACES_URI = "http://richfaces.org/rich"; //$NON-NLS-1$
private static String A4J_URI = "http://richfaces.org/a4j"; //$NON-NLS-1$
+ private static String FACELETS_URI = "http://java.sun.com/jsf/facelets"; //$NON-NLS-1$
/*
* (non-Javadoc)
@@ -67,7 +68,8 @@
&& (JSF_CORE_URI.equalsIgnoreCase(sourceNodeUri)
|| JSF_HTML_URI.equalsIgnoreCase(sourceNodeUri)
|| RICH_FACES_URI.equalsIgnoreCase(sourceNodeUri)
- || A4J_URI.equalsIgnoreCase(sourceNodeUri))) {
+ || A4J_URI.equalsIgnoreCase(sourceNodeUri)
+ || FACELETS_URI.equalsIgnoreCase(sourceNodeUri))) {
VpeChildrenInfo childrenInfo = new VpeChildrenInfo(div);
childrenInfo.addSourceChild(child);
creationData.addChildrenInfo(childrenInfo);
16 years
JBoss Tools SVN: r12962 - trunk/smooks/docs/reference/en/modules.
by jbosstools-commits@lists.jboss.org
Author: smukhina
Date: 2009-01-09 09:14:01 -0500 (Fri, 09 Jan 2009)
New Revision: 12962
Modified:
trunk/smooks/docs/reference/en/modules/introduction.xml
trunk/smooks/docs/reference/en/modules/quick_start.xml
trunk/smooks/docs/reference/en/modules/smooksformeditor_configurationpage.xml
trunk/smooks/docs/reference/en/modules/smooksformeditor_graphicalpage.xml
trunk/smooks/docs/reference/en/modules/smooksformeditor_sourcepage.xml
Log:
https://jira.jboss.org/jira/browse/JBIDE-3296 correcting language for Smooks guide
all chapters are corrected
Modified: trunk/smooks/docs/reference/en/modules/introduction.xml
===================================================================
--- trunk/smooks/docs/reference/en/modules/introduction.xml 2009-01-09 12:02:48 UTC (rev 12961)
+++ trunk/smooks/docs/reference/en/modules/introduction.xml 2009-01-09 14:14:01 UTC (rev 12962)
@@ -11,7 +11,7 @@
<title>Introduction</title>
<sect1>
<title>What is Smooks?</title>
- <para>Smooks is a Java Framework/Engine for processing XML and non XML data (CSV, EDI, Java, JSON etc).</para>
+ <para>Smooks is a Java Framework/Engine for processing XML and non XML data (CSV, EDI, Java, JSON etc).</para>
<para></para>
<para>
<orderedlist numeration="Upperroman" inheritnum="inherit">
@@ -52,7 +52,7 @@
</sect1>
<sect1>
<title>What is Smooks dev tools?</title>
- <para>Smooks dev tools is a set of graphical tools for editing Smooks configuration file base on Eclipse.</para>
+ <para>Smooks dev tools is a set of graphical tools for editing Smooks configuration file base on Eclipse.</para>
<figure>
<title>Smooks form editor</title>
<mediaobject>
@@ -69,10 +69,10 @@
</link>
.
</para>
- <para> Smooks dev tools (JBossTools) run with the latest Eclipse and other required plug-ins (GEF, EMF, etc.).</para>
- <para> You should download the latest IDE for Java EE developers from this
+ <para> Smooks dev tools (JBossTools) run with the latest Eclipse and other required plug-ins (GEF, EMF, etc.).</para>
+ <para> You should download the latest IDE for Java EE developers from this
<link linkend="http://www.eclipse.org/downloads/">site
- </link>. It contains many plug-ins ( GEF, EMF, etc. ) required by Smooks dev tools.
+ </link>. It contains many plug-ins ( GEF, EMF, etc. ) required by Smooks dev tools.
</para>
</sect1>
</chapter>
Modified: trunk/smooks/docs/reference/en/modules/quick_start.xml
===================================================================
--- trunk/smooks/docs/reference/en/modules/quick_start.xml 2009-01-09 12:02:48 UTC (rev 12961)
+++ trunk/smooks/docs/reference/en/modules/quick_start.xml 2009-01-09 14:14:01 UTC (rev 12962)
@@ -11,29 +11,19 @@
</chapterinfo>
<title>Quick Start</title>
<para>
- This "Quick Start" will show how to use the Smooks tools to
- create/edit the Smooks configuration file for Java2Java
- data
- transformation.</para>
+ This "Quick Start" will show how to use the Smooks tools to create/edit the Smooks configuration file for Java2Java data transformation.</para>
<para>
- This chapter should give you a brief understanding of
- the
- Smooks
- dev tools.
+ This chapter should give you a brief understanding of the Smooks dev tools.
</para>
<section>
<title>Download Smooks Java-to-Java example</title>
<para> Visit
- <ulink
- url="http://www.smooks.org/documentation/documentation-smooks-1-1-x/examples/e...">here</ulink> to download the "java-to-java" example project.
+ <ulink url="http://www.smooks.org/documentation/documentation-smooks-1-1-x/examples/e...">here</ulink> to download the "java-to-java" example project.
</para>
<tip>
<title>Tip:</title>
<para>
- The example project is base on Maven, you suggest you to
- create a new eclipse Java project and copy the example code and .jar
- files from the example project paste them into the eclipse Java
- project.
+ The example project is base on Maven, you suggest you to create a new eclipse Java project and copy the example code and .jar files from the example project paste them into the eclipse Java project.
</para>
</tip>
</section>
@@ -179,30 +169,30 @@
<para>How to map it?</para>
<para> First, you should know what to transform:
<orderedlist numeration="loweralpha" inheritnum="inherit">
- <listitem><para>Bind the "customerName" property of the
+ <listitem><para>Bind the "customerName" property of the
Order#header to
the
"customerName" property of LineOrder.</para>
</listitem>
- <listitem><para>Bind the
+ <listitem><para>Bind the
"customerNumber" property of the Order#header to
the
"customerId"
property of LineOrder.</para>
</listitem>
- <listitem><para>Bind the "price" property of the OrderItem
+ <listitem><para>Bind the "price" property of the OrderItem
to
the
"unitPrice" property of
LineItem.</para>
</listitem>
- <listitem><para>Bind the "productId"
+ <listitem><para>Bind the "productId"
property
of the OrderItem to the
"productCode"
property of LineItem.</para>
</listitem>
- <listitem><para>Bind the
+ <listitem><para>Bind the
"quantity" property of the OrderItem to the
"unitQuantity"
property of
@@ -288,21 +278,11 @@
<para>
Why does the occur error?</para>
<para> You will find that, if you only connect the property node without connecting the parent node of the property, the "connection error" occur</para>
- <para>The
- connection of
- the "price-to-unitPrice" is
- the "Binding
- Connection",
- but it needs
- a "Instance
- Creation
- Connection" -the
- connection
- of
- the
+ <para>The connection of the "price-to-unitPrice" is the "Binding Connection",
+ but it needs a "Instance Creation Connection" -the connection of the
"OrderItem-to-LineItem".</para>
</tip>
- <para> After that, connect the quantity to the unitQuantity ; connect the productId to the productCode:
+ <para> After that, connect the quantity to the unitQuantity ; connect the productId to the productCode:
</para>
<figure>
<title>Complete mapping</title>
Modified: trunk/smooks/docs/reference/en/modules/smooksformeditor_configurationpage.xml
===================================================================
--- trunk/smooks/docs/reference/en/modules/smooksformeditor_configurationpage.xml 2009-01-09 12:02:48 UTC (rev 12961)
+++ trunk/smooks/docs/reference/en/modules/smooksformeditor_configurationpage.xml 2009-01-09 14:14:01 UTC (rev 12962)
@@ -22,26 +22,14 @@
</imageobject>
</mediaobject>
</figure>
- <para>
- The
- <link linkend="configurationpage_datedecoder">"Date Decoder"</link>
- can
- add/edit/remove on the
- configuration editor
- page.
+ <para> The <link linkend="configurationpage_datedecoder">"Date Decoder"</link> can add/edit/remove on the configuration editor page.
</para>
<para>
- The configuration also edit the
- <link linkend="configurationpage_parsetype">"Smooks parse type"</link>
- and manage
- the
- <link linkend="configurationpage_importfile">"Import File"</link>
- .
+ The configuration also edit the <link linkend="configurationpage_parsetype">"Smooks parse type"</link> and manage the <link linkend="configurationpage_importfile">"Import File"</link> .
</para>
<section id="configurationpage_parsetype">
<title>Smooks parse type</title>
- <para>Open the "Other configuration" section, we will see there
- is a set of radio buttons:</para>
+ <para>Open the "Other configuration" section, you will see there is a set of radio buttons:</para>
<figure>
<title>Smooks parse type</title>
<mediaobject>
@@ -58,8 +46,7 @@
<section id="configurationpage_importfile">
<title>Import file</title>
<para>
- Open the "Other configuration" section, there is a "Import
- File" list under the "Smooks parse type" buttons.
+ Open the "Other configuration" section, there is an "Import File" list under the "Smooks parse type" buttons.
</para>
<figure>
<title>Import File</title>
@@ -70,30 +57,22 @@
</mediaobject>
</figure>
<para>
- There are three buttons on the right side of the "File Import"
- list. You can click those to add/edit/remove the import files.
+ There are three buttons on the right side of the "File Import" list. You can click those to add/edit/remove the import files.
</para>
<tip>
<title>Tip</title>
<para>
- If the import file dosen't exist, the image of the import file
- will change to "Error Image".
- If you double-click the import file in
- the "Import File" list, the file will be open with a new default
- editor.
+ If the import file doesn't exist, the image of the import file will change to "Error Image". If you double-click the import file in the "Import File" list, the file will be opened with a new default editor.
</para>
</tip>
</section>
<section id="configurationpage_datedecoder">
<title>Date Decoder Detail Page</title>
<para>
- "Date Decoder" is a resourceConfig element in the Smooks
- configuration
- file.It describe how to transform the "Date" type.
+ "Date Decoder" is a resourceConfig element in the Smooks configuration file.It describing how to transform the "Date" type.
</para>
<para>
- Click "New" button to open the "New Resource Type" wizard
- dialog.</para>
+ Click "New" button to open the "New Resource Type" wizard dialog.</para>
<figure>
<title>Resource Type Selection Wizard</title>
<mediaobject>
@@ -104,29 +83,23 @@
</mediaobject>
</figure>
- <para>There are several resource type on the list. Select the
- "Date
- Decoder" and click "Finish" button, a new "Date Decoder" item
- was
- added and shown on the resource type list.
+ <para>There are several resource types on the list. Select the "Date Decoder" and click "Finish" button, a new "Date Decoder" item was added and shown on the resource type list.
</para>
<para>
- There are several parameters in the "Date Decoder"
- resourceConfig element:
+ There are several parameters in the "Date Decoder" resourceConfig element:
</para>
<para>
<orderedlist numeration="loweralpha" inheritnum="inherit">
- <listitem><para>locale-language</para>
+ <listitem><para>locale-language</para>
</listitem>
- <listitem><para>format</para>
+ <listitem><para>format</para>
</listitem>
- <listitem><para>locale-country</para>
+ <listitem><para>locale-country</para>
</listitem>
</orderedlist>
</para>
<para>
- You can modify the parameters of the "Date Decoder" item with the
- left detail page.
+ You can modify the parameters of the "Date Decoder" item with the left detail page.
</para>
<figure>
<title>Date Decoder Detail Page</title>
@@ -138,8 +111,8 @@
</mediaobject>
</figure>
<para>
- When you defined new "Date Decoder", they can use the
- <link linkend="graphicalpage_propertiesview"> "JavaBean Properties"</link> GUI to set the them to be the "Java type".
+ When you define a new "Date Decoder", it becomes possible to use the
+ <link linkend="graphicalpage_propertiesview"> "JavaBean Properties"</link> GUI to set it to the "Java type".
</para>
<!--
<para> The XML fragment generated by Smooks tools for the "Date
Modified: trunk/smooks/docs/reference/en/modules/smooksformeditor_graphicalpage.xml
===================================================================
--- trunk/smooks/docs/reference/en/modules/smooksformeditor_graphicalpage.xml 2009-01-09 12:02:48 UTC (rev 12961)
+++ trunk/smooks/docs/reference/en/modules/smooksformeditor_graphicalpage.xml 2009-01-09 14:14:01 UTC (rev 12962)
@@ -9,64 +9,47 @@
</keywordset>
</chapterinfo>
<title>Smooks Graphical Editor Page</title>
- <para>
- Smooks Graphical Editor Page is one tab of the Smooks Form
- Editor.
- </para>
+ <para> Smooks Graphical Editor Page is one tab of the Smooks Form Editor. </para>
<figure>
<title>Graphical Editor</title>
<mediaobject>
<imageobject>
- <imagedata fileref="images/java2java/correct_editor.png"
- scale="90" />
+ <imagedata fileref="images/java2java/correct_editor.png" scale="90"/>
</imageobject>
</mediaobject>
</figure>
- <para>
- This graphical editor could allow you to perform drug/drop operations
- with the nodes of transform data to map the source data to target
- data.
- </para>
- <para>
- When you save the changes in the graphical editor the correct Smooks
- configuration file content
- will be generated.
- </para>
+ <para> This graphical editor could allow you to perform drug/drop operations with the nodes of transform data to map the source data to target data. </para>
+ <para> When you save the changes in the graphical editor, the correct Smooks configuration file content will be generated. </para>
<section>
- <title>Introducing the areas of graphical editor</title>
- <para>Information on the topic could be found here
- <link linkend="quickstart_formeditor">"Quick Start/Smooks Form Editor"</link>
+ <title>Introducing the areas of graphical editor</title>
+ <para>Information on the topic could be found here <link linkend="quickstart_formeditor"
+ >"Quick Start/Smooks Form Editor"</link>
</para>
</section>
<section>
<title>Load source/target data</title>
- <para> Click the links under the data viewer, the data type selection wizard page will be shown.
- </para>
+ <para> Click the links under the data viewer, the data type selection wizard page will be shown. </para>
<figure>
<title>Data type selection wizard page</title>
<mediaobject>
<imageobject>
- <imagedata fileref="images/common/data_type_wizard.png"
- scale="90" />
+ <imagedata fileref="images/common/data_type_wizard.png" scale="90"/>
</imageobject>
</mediaobject>
</figure>
- <para> There are sets of transform data type on the wizard page, select one type and click
- <property>Next</property>
- , the data source selection wizard page will be shown.
- <tip>
+ <para> There are sets of transform data type on the wizard page, select one type and click
+ <property>Next</property> , the data source selection wizard page will be shown. <tip>
<title>Note</title>
- <para>
- For different data type, the data source selection wizard are
- different too. </para>
+ <para> For different data type, the data source selection wizards are different too.
+ </para>
</tip>
</para>
<figure>
<title>Java data source selection wizard page</title>
<mediaobject>
<imageobject>
- <imagedata fileref="images/java2java/java_data_selection_wizard.png"
- scale="90" />
+ <imagedata fileref="images/java2java/java_data_selection_wizard.png" scale="90"
+ />
</imageobject>
</mediaobject>
</figure>
@@ -75,73 +58,43 @@
<mediaobject>
<imageobject>
<imagedata fileref="images/xml2java/xml_filepath_selection_wizard.png"
- scale="90" />
+ scale="90"/>
</imageobject>
</mediaobject>
</figure>
- <para> When you finish the data selection (file path selection), Click
- <property>Finish</property>
- , the data viewer will display the selected data structure.
- </para>
+ <para> When you finish the data selection (file path selection), Click
+ <property>Finish</property> , the data viewer will display the selected data structure. </para>
</section>
<section>
<title>Using the graphical editor for mapping</title>
- <para>To get information on the topic please, read the
- <link linkend="quickstart_mapping">"Quick Start/Mapping"</link>
+ <para>To get information on the topic please, read the <link linkend="quickstart_mapping"
+ >"Quick Start/Mapping"</link>
</para>
</section>
<section>
<title>Error messages</title>
- <para>When you do any mapping operations, the Smooks tools validates the file content with "Mapping Logic", If there is any errors of the configuration file content
- , error messages are shown on the
- <link linkend="quickstart_formeditor">"Error
- message area"</link>
- .
- </para>
- <para> Please, read the
- <link linkend="quickstart_mapping">"Quick Start/Mapping"</link> to find how to fix the errors.
- </para>
+ <para>When you do any mapping operations, the Smooks tools validates the file content with
+ "Mapping Logic", If there are any errors of the configuration file content , error messages are shown on the <link linkend="quickstart_formeditor">"Error message area"</link>. </para>
+ <para> Please, read the <link linkend="quickstart_mapping">"Quick Start/Mapping"</link> to find how to fix the errors. </para>
</section>
<section id="graphicalpage_propertiesview">
<title>Properties Viewer</title>
- <para> You can edit the properties of the "connection lines" with the properties viewer.
- </para>
- <para> Select the menu: "Window -> Show View -> Other -> Properties", the properties viewer is opened.
- </para>
- <para>
- When you select on the connection lines, the properties viewer
- will show a set of section GUI for editing the properties of the
- connection line.
- </para>
+ <para> You can edit the properties of the "connection lines" with the properties viewer. </para>
+ <para> Select the menu: "Window -> Show View -> Other -> Properties", the properties viewer is opened. </para>
+ <para> When you select on the connection lines, the properties viewer will show a set of section GUI for editing the properties of the connection line. </para>
<tip>
<title>Tip</title>
- <para>
- This GUI on the properties viewer is displayed when the
- "Smooks
- Graphical Page" is active, if not, the properties viewer
- displays empty GUI.
- </para>
- <para>
- If the source data type of the selected connection line is
- "XML", The properties viewer shows a "XML Properties" section
- GUI.
- </para>
- <para>
- But if the source data type of the selected connection line is
- "Java", the "XML Properties" section GUI isn't 'displayed.
- </para>
- <para>
- It means that if the source/target data type of the selected
- connection line is different, the properties viewer shows
- different GUI.
- </para>
+ <para> This GUI on the properties viewer is displayed when the "Smooks Graphical Page"
+ is active, if not, the properties viewer displays empty GUI. </para>
+ <para> If the source data type of the selected connection line is "XML", The properties viewer shows a "XML Properties" section GUI. </para>
+ <para> But if the source data type of the selected connection line is "Java", the "XML Properties" section GUI isn't 'displayed. </para>
+ <para> It means that if the source/target data type of the selected connection line is different, the properties viewer shows different GUI. </para>
</tip>
<figure>
<title>JavaBean Properties Section</title>
<mediaobject>
<imageobject>
- <imagedata fileref="images/common/java_property_view.png"
- scale="90" />
+ <imagedata fileref="images/common/java_property_view.png" scale="90"/>
</imageobject>
</mediaobject>
</figure>
@@ -149,8 +102,7 @@
<title>XML properties section</title>
<mediaobject>
<imageobject>
- <imagedata fileref="images/common/xml_property_view.png"
- scale="90" />
+ <imagedata fileref="images/common/xml_property_view.png" scale="90"/>
</imageobject>
</mediaobject>
</figure>
@@ -158,8 +110,7 @@
<title>Mapping properties section</title>
<mediaobject>
<imageobject>
- <imagedata fileref="images/common/mapping_property_view.png"
- scale="90" />
+ <imagedata fileref="images/common/mapping_property_view.png" scale="90"/>
</imageobject>
</mediaobject>
</figure>
Modified: trunk/smooks/docs/reference/en/modules/smooksformeditor_sourcepage.xml
===================================================================
--- trunk/smooks/docs/reference/en/modules/smooksformeditor_sourcepage.xml 2009-01-09 12:02:48 UTC (rev 12961)
+++ trunk/smooks/docs/reference/en/modules/smooksformeditor_sourcepage.xml 2009-01-09 14:14:01 UTC (rev 12962)
@@ -25,7 +25,7 @@
</section>
<section>
<title>Error Messages GUI</title>
- <para>If the Smooks tools can't understand the configuration file or the configuration file is illegal (XML structure isn't right for Smooks configuration file, etc.), The error message panel will be displayed above the XML editor.
+ <para>If the Smooks tools can't understand the configuration file or the configuration file is illegal (XML structure isn't right for Smooks configuration file, etc.), The error message panel will be displayed above the XML editor.
</para>
<figure>
<title>Graphical Editor</title>
@@ -43,8 +43,7 @@
Graphical Editor, Configuration Editor ) are disabled.
</para>
<para>
- You can't edit the configuration file with other editors until
- file becomes valid.
+ You can't edit the configuration file with other editors until file becomes valid.
</para>
</note>
</section>
16 years
JBoss Tools SVN: r12961 - in trunk/hibernatetools/plugins/org.hibernate.eclipse.console/src/org/hibernate/eclipse: hqleditor and 1 other directory.
by jbosstools-commits@lists.jboss.org
Author: dgeraskov
Date: 2009-01-09 07:02:48 -0500 (Fri, 09 Jan 2009)
New Revision: 12961
Modified:
trunk/hibernatetools/plugins/org.hibernate.eclipse.console/src/org/hibernate/eclipse/criteriaeditor/CriteriaEditor.java
trunk/hibernatetools/plugins/org.hibernate.eclipse.console/src/org/hibernate/eclipse/hqleditor/HQLEditor.java
Log:
https://jira.jboss.org/jira/browse/JBIDE-3463
Modified: trunk/hibernatetools/plugins/org.hibernate.eclipse.console/src/org/hibernate/eclipse/criteriaeditor/CriteriaEditor.java
===================================================================
--- trunk/hibernatetools/plugins/org.hibernate.eclipse.console/src/org/hibernate/eclipse/criteriaeditor/CriteriaEditor.java 2009-01-09 11:17:59 UTC (rev 12960)
+++ trunk/hibernatetools/plugins/org.hibernate.eclipse.console/src/org/hibernate/eclipse/criteriaeditor/CriteriaEditor.java 2009-01-09 12:02:48 UTC (rev 12961)
@@ -45,6 +45,8 @@
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.ui.IEditorInput;
+import org.eclipse.ui.IWorkbenchPage;
+import org.eclipse.ui.PartInitException;
import org.eclipse.ui.editors.text.EditorsUI;
import org.eclipse.ui.texteditor.ChainedPreferenceStore;
import org.eclipse.ui.texteditor.IDocumentProvider;
@@ -55,6 +57,7 @@
import org.hibernate.eclipse.console.AbstractQueryEditor;
import org.hibernate.eclipse.console.HibernateConsoleMessages;
import org.hibernate.eclipse.console.HibernateConsolePlugin;
+import org.hibernate.eclipse.console.views.QueryPageTabView;
import org.hibernate.mapping.PersistentClass;
public class CriteriaEditor extends AbstractQueryEditor {
@@ -119,6 +122,13 @@
}
public void executeQuery(ConsoleConfiguration cfg) {
+ final IWorkbenchPage activePage = getEditorSite().getPage();
+ try {
+ activePage.showView(QueryPageTabView.ID);
+ } catch (PartInitException e) {
+ // ignore
+ }
+
cfg.executeBSHQuery(getQueryString(), getQueryInputModel().getCopyForQuery() );
}
Modified: trunk/hibernatetools/plugins/org.hibernate.eclipse.console/src/org/hibernate/eclipse/hqleditor/HQLEditor.java
===================================================================
--- trunk/hibernatetools/plugins/org.hibernate.eclipse.console/src/org/hibernate/eclipse/hqleditor/HQLEditor.java 2009-01-09 11:17:59 UTC (rev 12960)
+++ trunk/hibernatetools/plugins/org.hibernate.eclipse.console/src/org/hibernate/eclipse/hqleditor/HQLEditor.java 2009-01-09 12:02:48 UTC (rev 12961)
@@ -46,6 +46,8 @@
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.ui.IEditorInput;
+import org.eclipse.ui.IWorkbenchPage;
+import org.eclipse.ui.PartInitException;
import org.eclipse.ui.texteditor.DefaultRangeIndicator;
import org.eclipse.ui.texteditor.IDocumentProvider;
import org.eclipse.ui.texteditor.ITextEditorActionDefinitionIds;
@@ -56,6 +58,7 @@
import org.hibernate.eclipse.console.HibernateConsolePlugin;
import org.hibernate.eclipse.console.HibernateConsoleMessages;
import org.hibernate.eclipse.console.views.IQueryParametersPage;
+import org.hibernate.eclipse.console.views.QueryPageTabView;
import org.hibernate.eclipse.console.views.QueryParametersPage;
@@ -403,6 +406,13 @@
public void executeQuery(ConsoleConfiguration cfg) {
+ final IWorkbenchPage activePage = getEditorSite().getPage();
+ try {
+ activePage.showView(QueryPageTabView.ID);
+ } catch (PartInitException e) {
+ // ignore
+ }
+
cfg.executeHQLQuery(getQueryString(), getQueryInputModel().getCopyForQuery() );
}
16 years
JBoss Tools SVN: r12960 - in trunk/hibernatetools/plugins/org.jboss.tools.hibernate.jpt.core/src/org/jboss/tools/hibernate/jpt/core/internal: context and 1 other directory.
by jbosstools-commits@lists.jboss.org
Author: dgeraskov
Date: 2009-01-09 06:17:59 -0500 (Fri, 09 Jan 2009)
New Revision: 12960
Modified:
trunk/hibernatetools/plugins/org.jboss.tools.hibernate.jpt.core/src/org/jboss/tools/hibernate/jpt/core/internal/HibernateJpaAnnotationProvider.java
trunk/hibernatetools/plugins/org.jboss.tools.hibernate.jpt.core/src/org/jboss/tools/hibernate/jpt/core/internal/context/HibernatePersistenceUnit.java
Log:
https://jira.jboss.org/jira/browse/JBIDE-3454
annotation recognized for 'Type'
Modified: trunk/hibernatetools/plugins/org.jboss.tools.hibernate.jpt.core/src/org/jboss/tools/hibernate/jpt/core/internal/HibernateJpaAnnotationProvider.java
===================================================================
--- trunk/hibernatetools/plugins/org.jboss.tools.hibernate.jpt.core/src/org/jboss/tools/hibernate/jpt/core/internal/HibernateJpaAnnotationProvider.java 2009-01-09 11:11:19 UTC (rev 12959)
+++ trunk/hibernatetools/plugins/org.jboss.tools.hibernate.jpt.core/src/org/jboss/tools/hibernate/jpt/core/internal/HibernateJpaAnnotationProvider.java 2009-01-09 11:17:59 UTC (rev 12960)
@@ -11,6 +11,7 @@
package org.jboss.tools.hibernate.jpt.core.internal;
import java.util.Collection;
+import java.util.List;
import org.eclipse.jpt.core.internal.platform.GenericJpaAnnotationProvider;
import org.eclipse.jpt.core.resource.java.AnnotationDefinition;
@@ -22,13 +23,22 @@
*/
public class HibernateJpaAnnotationProvider extends GenericJpaAnnotationProvider {
- /* (non-Javadoc)
- * @see org.eclipse.jpt.core.internal.platform.GenericJpaAnnotationProvider#addAttributeAnnotationDefinitionsTo(java.util.Collection)
- */
@Override
+ protected void addTypeAnnotationDefinitionsTo(Collection<AnnotationDefinition> definitions) {
+ super.addTypeAnnotationDefinitionsTo(definitions);
+ definitions.add(GenericGeneratorAnnotationDefinition.instance());
+ }
+
+ @Override
+ protected void addAttributeMappingAnnotationDefinitionsTo(List<AnnotationDefinition> definitions) {
+ super.addAttributeMappingAnnotationDefinitionsTo(definitions);
+ definitions.add(GenericGeneratorAnnotationDefinition.instance());
+ }
+
+ @Override
protected void addAttributeAnnotationDefinitionsTo(Collection<AnnotationDefinition> definitions) {
super.addAttributeAnnotationDefinitionsTo(definitions);
definitions.add(GenericGeneratorAnnotationDefinition.instance());
- }
-
+ }
+
}
Modified: trunk/hibernatetools/plugins/org.jboss.tools.hibernate.jpt.core/src/org/jboss/tools/hibernate/jpt/core/internal/context/HibernatePersistenceUnit.java
===================================================================
--- trunk/hibernatetools/plugins/org.jboss.tools.hibernate.jpt.core/src/org/jboss/tools/hibernate/jpt/core/internal/context/HibernatePersistenceUnit.java 2009-01-09 11:11:19 UTC (rev 12959)
+++ trunk/hibernatetools/plugins/org.jboss.tools.hibernate.jpt.core/src/org/jboss/tools/hibernate/jpt/core/internal/context/HibernatePersistenceUnit.java 2009-01-09 11:17:59 UTC (rev 12960)
@@ -11,6 +11,7 @@
package org.jboss.tools.hibernate.jpt.core.internal.context;
import java.io.File;
+import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
@@ -24,16 +25,23 @@
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.Path;
+import org.eclipse.jpt.core.context.Generator;
+import org.eclipse.jpt.core.context.java.JavaGenerator;
import org.eclipse.jpt.core.context.java.JavaPersistentAttribute;
import org.eclipse.jpt.core.context.java.JavaPersistentType;
import org.eclipse.jpt.core.context.persistence.ClassRef;
import org.eclipse.jpt.core.context.persistence.Persistence;
import org.eclipse.jpt.core.context.persistence.Property;
import org.eclipse.jpt.core.internal.context.persistence.GenericPersistenceUnit;
+import org.eclipse.jpt.core.internal.validation.DefaultJpaValidationMessages;
+import org.eclipse.jpt.core.internal.validation.JpaValidationMessages;
import org.eclipse.jpt.core.resource.java.JavaResourcePersistentAttribute;
+import org.eclipse.jpt.core.resource.java.JavaResourcePersistentMember;
+import org.eclipse.jpt.core.resource.java.JavaResourcePersistentType;
import org.eclipse.jpt.core.resource.persistence.XmlPersistenceUnit;
import org.eclipse.jpt.core.resource.persistence.XmlProperties;
import org.eclipse.jpt.core.resource.persistence.XmlProperty;
+import org.eclipse.jpt.core.utility.TextRange;
import org.eclipse.jpt.utility.internal.CollectionTools;
import org.eclipse.jpt.utility.internal.iterators.CloneIterator;
import org.eclipse.jpt.utility.internal.iterators.EmptyIterator;
@@ -79,7 +87,7 @@
super.addToMessages(messages);
addFileNotExistsMessages(messages);
}
-
+
protected void addFileNotExistsMessages(List<IMessage> messages) {
String configFile = getBasicProperties().getConfigurationFile();
if (configFile != null && configFile.length() > 0){
@@ -87,7 +95,6 @@
if (new File(path.toOSString()).exists()) return;
-
IResource res= ResourcesPlugin.getWorkspace().getRoot().findMember(path);
if (res != null) {
int resType= res.getType();
@@ -168,16 +175,21 @@
}
protected void updateGenericGenerators(){
- for (String annotClass : CollectionTools.iterable(getJpaProject().annotatedClassNames())) {
- ClassRef classRef = buildClassRef(annotClass);
+ for (String annotClass : CollectionTools.iterable(getJpaProject().annotatedClassNames())) {
+ ClassRef classRef = buildClassRef(annotClass);
JavaPersistentType type = classRef.getJavaPersistentType();
- ListIterator<JavaPersistentAttribute> typeAttrs = type.attributes();
+ JavaResourcePersistentMember jrpt = getJpaProject().getJavaPersistentTypeResource(annotClass);
+ GenericGeneratorAnnotation annotation = (GenericGeneratorAnnotation) jrpt.getAnnotation(GENERIC_GENERATOR);
+ if (annotation != null) {
+ addGenerator(annotation.buildJavaGenericGenerator(type));
+ }
+
+ ListIterator<JavaPersistentAttribute> typeAttrs = type.attributes();
for (JavaPersistentAttribute persAttr : CollectionTools.iterable(typeAttrs)) {
JavaResourcePersistentAttribute jrpa = persAttr.getResourcePersistentAttribute();
- GenericGeneratorAnnotation annotation = (GenericGeneratorAnnotation) jrpa.getAnnotation(GENERIC_GENERATOR);
+ annotation = (GenericGeneratorAnnotation) jrpa.getAnnotation(GENERIC_GENERATOR);
if (annotation != null){
- JavaGenericGenerator generator = annotation.buildJavaGenericGenerator(persAttr.getSpecifiedMapping());
- addGenerator(generator);
+ addGenerator(annotation.buildJavaGenericGenerator(persAttr.getSpecifiedMapping()));
}
}
}
16 years
JBoss Tools SVN: r12959 - trunk/jsf/tests/org.jboss.tools.jsf.vpe.richfaces.test/src/org/jboss/tools/jsf/vpe/richfaces/test/jbide.
by jbosstools-commits@lists.jboss.org
Author: dmaliarevich
Date: 2009-01-09 06:11:19 -0500 (Fri, 09 Jan 2009)
New Revision: 12959
Modified:
trunk/jsf/tests/org.jboss.tools.jsf.vpe.richfaces.test/src/org/jboss/tools/jsf/vpe/richfaces/test/jbide/JBIDE1605Test.java
Log:
Junit test was updated.
Modified: trunk/jsf/tests/org.jboss.tools.jsf.vpe.richfaces.test/src/org/jboss/tools/jsf/vpe/richfaces/test/jbide/JBIDE1605Test.java
===================================================================
--- trunk/jsf/tests/org.jboss.tools.jsf.vpe.richfaces.test/src/org/jboss/tools/jsf/vpe/richfaces/test/jbide/JBIDE1605Test.java 2009-01-09 09:49:26 UTC (rev 12958)
+++ trunk/jsf/tests/org.jboss.tools.jsf.vpe.richfaces.test/src/org/jboss/tools/jsf/vpe/richfaces/test/jbide/JBIDE1605Test.java 2009-01-09 11:11:19 UTC (rev 12959)
@@ -38,7 +38,7 @@
private static final String PAGE = "components/panelMenuGroup/jbide1605.xhtml"; //$NON-NLS-1$
/** The Constant COUNT_OF_DIVS. */
- private static final int COUNT_OF_DIVS = 17;
+ private static final int COUNT_OF_DIVS = 16;
/**
* The Constructor.
16 years
--- trunk/vpe/plugins/org.jboss.tools.vpe.html/src/org/jboss/tools/vpe/html/template/HtmlTextTemplate.java 2009-01-10 13:25:41 UTC (rev 12967)
+++ trunk/vpe/plugins/org.jboss.tools.vpe.html/src/org/jboss/tools/vpe/html/template/HtmlTextTemplate.java 2009-01-10 13:43:11 UTC (rev 12968)
@@ -16,8 +16,8 @@
import org.jboss.tools.vpe.editor.mapping.VpeElementData;
import org.jboss.tools.vpe.editor.template.VpeAbstractTemplate;
import org.jboss.tools.vpe.editor.template.VpeCreationData;
-import org.jboss.tools.vpe.editor.util.HTML;
import org.jboss.tools.vpe.editor.util.TextUtil;
+import org.jboss.tools.vpe.editor.util.VisualDomUtil;
import org.mozilla.interfaces.nsIDOMDocument;
import org.mozilla.interfaces.nsIDOMElement;
import org.mozilla.interfaces.nsIDOMNode;
@@ -43,9 +43,8 @@
nsIDOMNode visualNewTextNode = visualDocument
.createTextNode(visualText);
- //Max Areshkau without this span, we can't select text element
- nsIDOMElement element = visualDocument.createElement(HTML.TAG_SPAN);
- element.setAttribute(HTML.ATTR_CLASS, HTML.CLASS_VPE_TEXT);
+ //Max Areshkau without this container, we can't select text element
+ nsIDOMElement element = VisualDomUtil.createBorderlessContainer(visualDocument);
element.appendChild(visualNewTextNode);
VpeElementData textElementData = new VpeElementData();
@@ -55,5 +54,5 @@
result.setElementData(textElementData);
return result;
- }
+ }
}
16 years
JBoss Tools SVN: r12967 - in trunk: vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor and 1 other directory.
by jbosstools-commits@lists.jboss.org
Author: mareshkau
Date: 2009-01-10 08:25:41 -0500 (Sat, 10 Jan 2009)
New Revision: 12967
Modified:
trunk/jsf/tests/org.jboss.tools.jsf.vpe.jsf.test/src/org/jboss/tools/jsf/vpe/jsf/test/jbide/JBIDE3441Test.java
trunk/vpe/plugins/org.jboss.tools.vpe/src/org/jboss/tools/vpe/editor/VpeController.java
Log:
https://jira.jboss.org/jira/browse/JBIDE-3441, reinit method was moved to job
Modified: trunk/jsf/tests/org.jboss.tools.jsf.vpe.jsf.test/src/org/jboss/tools/jsf/vpe/jsf/test/jbide/JBIDE3441Test.java
===================================================================